__version__ = "0.1.0"

from .pattern_search import run_pattern_search
from .parser_registry import get_parse_files, list_parsers
from .verovio_render import (
    get_toolkit as vrv_get_toolkit,
    vrv_set_options,
    vrv_guess_input_from,
    vrv_load_data,
    vrv_load_from_file,
    vrv_load_from_url,
    vrv_convert_to_mei,
    vrv_render_page,
    vrv_render_all_pages,
    vrv_display_svg,
    vrv_find_elements_at_time,
    vrv_timemap,
    vrv_get_mei,
    vrv_set_mei,
    vrv_insert_annot,
    vrv_has_mei_export,
    vrv_set_additional_css,
    vrv_highlight_ids,
    vrv_debug_info,
    vrv_inject_highlight_css,
    vrv_insert_annot_plist,
    vrv_insert_annots_by_tstamps,
    vrv_process_annotations,
    vrv_namespaces,
)
from .overlay import (
    select_metric_df,
    kernel_from_variants,
    compute_top_matches_df,
    build_match_records,
    build_overlay_source,
    overlay_top_matches_on_piano_roll,
)
from .analysis_utils import (
    parse_pitch_name,
    name_to_midi,
    midi_to_name,
    build_pitch_counts,
    sort_pitch_counts,
    plot_pitch_distribution,
    display_pitch_distribution,
    build_pc_counts_from_names,
    build_pitch_class_distributions,
    display_pitch_class_distributions,
    display_filtered_piano_roll,
    extract_selected_xml_ids,
)
from .parser_utils import (
    expand_file_sources,
    format_parsed_summary,
    print_parsed_summary,
)

__all__ = [
    '__version__',
    'run_pattern_search',
    'get_parse_files',
    'list_parsers',
    'vrv_get_toolkit',
    'vrv_set_options',
    'vrv_guess_input_from',
    'vrv_load_data',
    'vrv_load_from_file',
    'vrv_load_from_url',
    'vrv_convert_to_mei',
    'vrv_render_page',
    'vrv_render_all_pages',
    'vrv_display_svg',
    'vrv_find_elements_at_time',
    'vrv_timemap',
    'vrv_get_mei',
    'vrv_set_mei',
    'vrv_insert_annot',
    'vrv_has_mei_export',
    'vrv_set_additional_css',
    'vrv_highlight_ids',
    'vrv_debug_info',
    'vrv_inject_highlight_css',
    'vrv_insert_annot_plist',
    'vrv_insert_annots_by_tstamps',
    'vrv_process_annotations',
    'vrv_namespaces',
    'select_metric_df',
    'kernel_from_variants',
    'compute_top_matches_df',
    'build_match_records',
    'build_overlay_source',
    'overlay_top_matches_on_piano_roll',
    'parse_pitch_name',
    'name_to_midi',
    'midi_to_name',
    'build_pitch_counts',
    'sort_pitch_counts',
    'plot_pitch_distribution',
    'display_pitch_distribution',
    'build_pc_counts_from_names',
    'build_pitch_class_distributions',
    'display_pitch_class_distributions',
    'display_filtered_piano_roll',
    'extract_selected_xml_ids',
    'expand_file_sources',
    'format_parsed_summary',
    'print_parsed_summary',
]
